@@ -1,13 +1,14 @@
 from flask import Blueprint
 
 from pitop.labs.web.blueprints.base import BaseBlueprint
-from pitop.labs.web.blueprints.webcomponents import WebComponentsBlueprint
 from pitop.labs.web.blueprints.messaging import MessagingBlueprint
 from pitop.labs.web.blueprints.video import VideoBlueprint
+from pitop.labs.web.blueprints.webcomponents import WebComponentsBlueprint
 
 
 class ControllerBlueprint(Blueprint):
-    def __init__(self, get_frame=None, message_handlers={}, **kwargs):
+    def __init__(self, get_frame=None, message_handlers=None, **kwargs):
+        message_handlers = {} if message_handlers is None else message_handlers
         Blueprint.__init__(
             self,
             "controller",
@@ -20,8 +21,7 @@ class ControllerBlueprint(Blueprint):
         self.base_blueprint = BaseBlueprint()
         self.components_blueprint = WebComponentsBlueprint()
         self.video_blueprint = VideoBlueprint(get_frame=get_frame)
-        self.messaging_blueprint = MessagingBlueprint(
-            message_handlers=message_handlers)
+        self.messaging_blueprint = MessagingBlueprint(message_handlers=message_handlers)
 
     def register(self, app, options, *args, **kwargs):
         # register child blueprints
