@@ -1,9 +1,9 @@
 from flask import Flask, render_template, send_from_directory
 from flask_cors import CORS
-from flask_sockets import Sockets
 from gevent.pywsgi import WSGIServer
 from geventwebsocket.handler import WebSocketHandler
 
+from pitop.common.flask_sockets import Sockets
 from pitop.common.formatting import is_url
 from pitop.common.sys_info import get_internal_ip
 
